@@ -1,5 +1,5 @@
-#ifndef _GNM_GUI_FILE_H_
-# define _GNM_GUI_FILE_H_
+#ifndef GNM_GUI_FILE_H_
+#define GNM_GUI_FILE_H_
 
 #include <gnumeric-fwd.h>
 
@@ -17,7 +17,8 @@ typedef enum {
 
 gboolean gui_file_save_as   (WBCGtk *wbcg, WorkbookView *wbv,
 			     GnmFileSaveAsStyle type,
-			     char const *default_format);
+			     char const *default_format,
+			     gboolean from_save);
 gboolean gui_file_save      (WBCGtk *wbcg, WorkbookView *wbv);
 gboolean gui_file_export_repeat (WBCGtk *wbcg);
 void     gui_file_open      (WBCGtk *wbcg, GnmFileOpenStyle type,
@@ -30,4 +31,4 @@ gboolean gnm_gui_file_template  (WBCGtk *wbcg, char const *uri);
 
 G_END_DECLS
 
-#endif /* _GNM_GUI_FILE_H_ */
+#endif /* GNM_GUI_FILE_H_ */
