@@ -1,5 +1,5 @@
-#ifndef _GNM_SHEET_OBJECT_WIDGET_IMPL_H_
-# define _GNM_SHEET_OBJECT_WIDGET_IMPL_H_
+#ifndef GNM_SHEET_OBJECT_WIDGET_IMPL_H_
+#define GNM_SHEET_OBJECT_WIDGET_IMPL_H_
 
 #include <sheet-object-widget.h>
 #include <sheet-object-impl.h>
@@ -16,4 +16,4 @@ typedef struct {
 
 G_END_DECLS
 
-#endif /* _GNM_SHEET_OBJECT_WIDGET_H_ */
+#endif /* GNM_SHEET_OBJECT_WIDGET_H_ */
