@@ -22,8 +22,8 @@
  */
 
 
-#ifndef ANALYSIS_PRINCIPAL_COMPONENTS_H
-#define ANALYSIS_PRINCIPAL_COMPONENTS_H
+#ifndef GNM_TOOLS_ANALYSIS_PRINCIPAL_COMPONENTS_H_
+#define GNM_TOOLS_ANALYSIS_PRINCIPAL_COMPONENTS_H_
 
 #include <gnumeric.h>
 #include <numbers.h>
